@@ -94,7 +94,7 @@ MODULE = 'authres'
 
 __author__  = 'Julian Mehnle, Scott Kitterman'
 __email__   = 'julian@mehnle.net'
-__version__ = '0.701'
+__version__ = '0.800'
 
 import authres.core
 
@@ -184,12 +184,14 @@ def all_features():
         import authres.vbr
         import authres.dmarc
         import authres.smime
+        import authres.rrvs
         _all_features = FeatureContext(
             authres.dkim_b,
             authres.dkim_adsp,
             authres.vbr,
             authres.dmarc,
-            authres.smime
+            authres.smime,
+            authres.rrvs
         )
     return _all_features
 
